SBSManip (sbsmanip)
===================

SBSManip is a collection of utilities to manipulate Space Engineers configuration and savefiles along with a front end designed to clean up savefiles.

Space Engineers Garbage Collect (segc)
--------------------------------------

SEGC is the cli frontend to clean up SE savefiles and provides a means to clean up debris, remove instances of specific ships, remove entities based on distance from origin, and retrieve statistics for a save. SEGC is primarily designed to assist server operators.

Installation
------------

To install the package, simply use pip:

    pip install sbsmanip